NAME
IO::K8s::AgentSandbox::V1alpha1::SandboxWarmPool - Pre-warmed pool of sandbox instances
VERSION
version 1.100
DESCRIPTION
SandboxWarmPool manages a pool of pre-warmed Sandbox instances for quick allocation, reducing startup latency. This is a namespace-scoped resource using API version extensions.agents.x-k8s.io/v1alpha1. The spec and status fields are typed inline structs generated from the upstream AgentSandbox Go types.
SEE ALSO
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/pplu/io-k8s-p5/issues.
IRC
Join #kubernetes on irc.perl.org or message Getty directly.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHORS
Torsten Raudssus <torsten@raudssus.de>
Jose Luis Martinez Torres <jlmartin@cpan.org>
COPYRIGHT AND LICENSE
This software is Copyright (c) 2018-2026 by Jose Luis Martinez Torres <jlmartin@cpan.org>.
This is free software, licensed under:
The Apache License, Version 2.0, January 2004