NAME
IO::K8s::ApiextensionsApiserver::Pkg::Apis::Apiextensions::V1::CustomResourceDefinitionVersion - CustomResourceDefinitionVersion describes a version for CRD.
VERSION
version 1.006
additionalPrinterColumns
additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used.
deprecated
deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false.
deprecationWarning
deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.
name
name is the version name, e.g. "v1", "v2beta1", etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true.
schema
schema describes the schema used for validation, pruning, and defaulting of this version of the custom resource.
selectableFields
selectableFields specifies paths to fields that may be used as field selectors. A maximum of 8 selectable fields are allowed. See https://kubernetes.io/docs/concepts/overview/working-with-objects/field-selectors
served
served is a flag enabling/disabling this version from being served via REST APIs
storage
storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true.
subresources
subresources specify what subresources this version of the defined custom resource have.
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/pplu/io-k8s-p5/issues.
IRC
Join #kubernetes on irc.perl.org or message Getty directly.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHORS
Torsten Raudssus <torsten@raudssus.de>
Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)
COPYRIGHT AND LICENSE
This software is Copyright (c) 2018 by Jose Luis Martinez.
This is free software, licensed under:
The Apache License, Version 2.0, January 2004